# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2paymentsTravelInformationTransitAirline(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'booking_reference_number': 'str',
        'carrier_name': 'str',
        'ticket_issuer': 'Ptsv2paymentsTravelInformationTransitAirlineTicketIssuer',
        'ticket_number': 'str',
        'check_digit': 'str',
        'restricted_ticket_indicator': 'int',
        'transaction_type': 'int',
        'extended_payment_code': 'str',
        'passenger_name': 'str',
        'customer_code': 'str',
        'document_type': 'str',
        'document_number': 'str',
        'document_number_of_parts': 'int',
        'invoice_number': 'str',
        'invoice_date': 'int',
        'additional_charges': 'str',
        'total_fee_amount': 'str',
        'clearing_sequence': 'str',
        'clearing_count': 'str',
        'total_clearing_amount': 'str',
        'number_of_passengers': 'int',
        'reservation_system_code': 'str',
        'process_identifier': 'str',
        'ticket_issue_date': 'str',
        'electronic_ticket_indicator': 'bool',
        'original_ticket_number': 'str',
        'purchase_type': 'str',
        'credit_reason_indicator': 'str',
        'ticket_change_indicator': 'str',
        'plan_number': 'str',
        'arrival_date': 'str',
        'restricted_ticket_desciption': 'str',
        'exchange_ticket_amount': 'str',
        'exchange_ticket_fee_amount': 'str',
        'reservation_type': 'str',
        'boarding_fee_amount': 'str',
        'legs': 'list[Ptsv2paymentsTravelInformationTransitAirlineLegs]',
        'ancillary_information': 'Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation'
    }

    attribute_map = {
        'booking_reference_number': 'bookingReferenceNumber',
        'carrier_name': 'carrierName',
        'ticket_issuer': 'ticketIssuer',
        'ticket_number': 'ticketNumber',
        'check_digit': 'checkDigit',
        'restricted_ticket_indicator': 'restrictedTicketIndicator',
        'transaction_type': 'transactionType',
        'extended_payment_code': 'extendedPaymentCode',
        'passenger_name': 'passengerName',
        'customer_code': 'customerCode',
        'document_type': 'documentType',
        'document_number': 'documentNumber',
        'document_number_of_parts': 'documentNumberOfParts',
        'invoice_number': 'invoiceNumber',
        'invoice_date': 'invoiceDate',
        'additional_charges': 'additionalCharges',
        'total_fee_amount': 'totalFeeAmount',
        'clearing_sequence': 'clearingSequence',
        'clearing_count': 'clearingCount',
        'total_clearing_amount': 'totalClearingAmount',
        'number_of_passengers': 'numberOfPassengers',
        'reservation_system_code': 'reservationSystemCode',
        'process_identifier': 'processIdentifier',
        'ticket_issue_date': 'ticketIssueDate',
        'electronic_ticket_indicator': 'electronicTicketIndicator',
        'original_ticket_number': 'originalTicketNumber',
        'purchase_type': 'purchaseType',
        'credit_reason_indicator': 'creditReasonIndicator',
        'ticket_change_indicator': 'ticketChangeIndicator',
        'plan_number': 'planNumber',
        'arrival_date': 'arrivalDate',
        'restricted_ticket_desciption': 'restrictedTicketDesciption',
        'exchange_ticket_amount': 'exchangeTicketAmount',
        'exchange_ticket_fee_amount': 'exchangeTicketFeeAmount',
        'reservation_type': 'reservationType',
        'boarding_fee_amount': 'boardingFeeAmount',
        'legs': 'legs',
        'ancillary_information': 'ancillaryInformation'
    }

    def __init__(self, booking_reference_number=None, carrier_name=None, ticket_issuer=None, ticket_number=None, check_digit=None, restricted_ticket_indicator=None, transaction_type=None, extended_payment_code=None, passenger_name=None, customer_code=None, document_type=None, document_number=None, document_number_of_parts=None, invoice_number=None, invoice_date=None, additional_charges=None, total_fee_amount=None, clearing_sequence=None, clearing_count=None, total_clearing_amount=None, number_of_passengers=None, reservation_system_code=None, process_identifier=None, ticket_issue_date=None, electronic_ticket_indicator=None, original_ticket_number=None, purchase_type=None, credit_reason_indicator=None, ticket_change_indicator=None, plan_number=None, arrival_date=None, restricted_ticket_desciption=None, exchange_ticket_amount=None, exchange_ticket_fee_amount=None, reservation_type=None, boarding_fee_amount=None, legs=None, ancillary_information=None):
        """
        Ptsv2paymentsTravelInformationTransitAirline - a model defined in Swagger
        """

        self._booking_reference_number = None
        self._carrier_name = None
        self._ticket_issuer = None
        self._ticket_number = None
        self._check_digit = None
        self._restricted_ticket_indicator = None
        self._transaction_type = None
        self._extended_payment_code = None
        self._passenger_name = None
        self._customer_code = None
        self._document_type = None
        self._document_number = None
        self._document_number_of_parts = None
        self._invoice_number = None
        self._invoice_date = None
        self._additional_charges = None
        self._total_fee_amount = None
        self._clearing_sequence = None
        self._clearing_count = None
        self._total_clearing_amount = None
        self._number_of_passengers = None
        self._reservation_system_code = None
        self._process_identifier = None
        self._ticket_issue_date = None
        self._electronic_ticket_indicator = None
        self._original_ticket_number = None
        self._purchase_type = None
        self._credit_reason_indicator = None
        self._ticket_change_indicator = None
        self._plan_number = None
        self._arrival_date = None
        self._restricted_ticket_desciption = None
        self._exchange_ticket_amount = None
        self._exchange_ticket_fee_amount = None
        self._reservation_type = None
        self._boarding_fee_amount = None
        self._legs = None
        self._ancillary_information = None

        if booking_reference_number is not None:
          self.booking_reference_number = booking_reference_number
        if carrier_name is not None:
          self.carrier_name = carrier_name
        if ticket_issuer is not None:
          self.ticket_issuer = ticket_issuer
        if ticket_number is not None:
          self.ticket_number = ticket_number
        if check_digit is not None:
          self.check_digit = check_digit
        if restricted_ticket_indicator is not None:
          self.restricted_ticket_indicator = restricted_ticket_indicator
        if transaction_type is not None:
          self.transaction_type = transaction_type
        if extended_payment_code is not None:
          self.extended_payment_code = extended_payment_code
        if passenger_name is not None:
          self.passenger_name = passenger_name
        if customer_code is not None:
          self.customer_code = customer_code
        if document_type is not None:
          self.document_type = document_type
        if document_number is not None:
          self.document_number = document_number
        if document_number_of_parts is not None:
          self.document_number_of_parts = document_number_of_parts
        if invoice_number is not None:
          self.invoice_number = invoice_number
        if invoice_date is not None:
          self.invoice_date = invoice_date
        if additional_charges is not None:
          self.additional_charges = additional_charges
        if total_fee_amount is not None:
          self.total_fee_amount = total_fee_amount
        if clearing_sequence is not None:
          self.clearing_sequence = clearing_sequence
        if clearing_count is not None:
          self.clearing_count = clearing_count
        if total_clearing_amount is not None:
          self.total_clearing_amount = total_clearing_amount
        if number_of_passengers is not None:
          self.number_of_passengers = number_of_passengers
        if reservation_system_code is not None:
          self.reservation_system_code = reservation_system_code
        if process_identifier is not None:
          self.process_identifier = process_identifier
        if ticket_issue_date is not None:
          self.ticket_issue_date = ticket_issue_date
        if electronic_ticket_indicator is not None:
          self.electronic_ticket_indicator = electronic_ticket_indicator
        if original_ticket_number is not None:
          self.original_ticket_number = original_ticket_number
        if purchase_type is not None:
          self.purchase_type = purchase_type
        if credit_reason_indicator is not None:
          self.credit_reason_indicator = credit_reason_indicator
        if ticket_change_indicator is not None:
          self.ticket_change_indicator = ticket_change_indicator
        if plan_number is not None:
          self.plan_number = plan_number
        if arrival_date is not None:
          self.arrival_date = arrival_date
        if restricted_ticket_desciption is not None:
          self.restricted_ticket_desciption = restricted_ticket_desciption
        if exchange_ticket_amount is not None:
          self.exchange_ticket_amount = exchange_ticket_amount
        if exchange_ticket_fee_amount is not None:
          self.exchange_ticket_fee_amount = exchange_ticket_fee_amount
        if reservation_type is not None:
          self.reservation_type = reservation_type
        if boarding_fee_amount is not None:
          self.boarding_fee_amount = boarding_fee_amount
        if legs is not None:
          self.legs = legs
        if ancillary_information is not None:
          self.ancillary_information = ancillary_information

    @property
    def booking_reference_number(self):
        """
        Gets the booking_reference_number of this Ptsv2paymentsTravelInformationTransitAirline.
        Reference number for the airline booking. Required if ticket numbers are not issued. 

        :return: The booking_reference_number of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._booking_reference_number

    @booking_reference_number.setter
    def booking_reference_number(self, booking_reference_number):
        """
        Sets the booking_reference_number of this Ptsv2paymentsTravelInformationTransitAirline.
        Reference number for the airline booking. Required if ticket numbers are not issued. 

        :param booking_reference_number: The booking_reference_number of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if booking_reference_number is not None and len(booking_reference_number) > 15:
            raise ValueError("Invalid value for `booking_reference_number`, length must be less than or equal to `15`")

        self._booking_reference_number = booking_reference_number

    @property
    def carrier_name(self):
        """
        Gets the carrier_name of this Ptsv2paymentsTravelInformationTransitAirline.
        Airline that generated the ticket. Format: English characters only. Optional request field. 

        :return: The carrier_name of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._carrier_name

    @carrier_name.setter
    def carrier_name(self, carrier_name):
        """
        Sets the carrier_name of this Ptsv2paymentsTravelInformationTransitAirline.
        Airline that generated the ticket. Format: English characters only. Optional request field. 

        :param carrier_name: The carrier_name of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if carrier_name is not None and len(carrier_name) > 15:
            raise ValueError("Invalid value for `carrier_name`, length must be less than or equal to `15`")

        self._carrier_name = carrier_name

    @property
    def ticket_issuer(self):
        """
        Gets the ticket_issuer of this Ptsv2paymentsTravelInformationTransitAirline.

        :return: The ticket_issuer of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: Ptsv2paymentsTravelInformationTransitAirlineTicketIssuer
        """
        return self._ticket_issuer

    @ticket_issuer.setter
    def ticket_issuer(self, ticket_issuer):
        """
        Sets the ticket_issuer of this Ptsv2paymentsTravelInformationTransitAirline.

        :param ticket_issuer: The ticket_issuer of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: Ptsv2paymentsTravelInformationTransitAirlineTicketIssuer
        """

        self._ticket_issuer = ticket_issuer

    @property
    def ticket_number(self):
        """
        Gets the ticket_number of this Ptsv2paymentsTravelInformationTransitAirline.
        Ticket number. Format: English characters only. Restricted string data type that indicates a sequence of letters, numbers, and spaces; special characters are not included. Optional request field. 

        :return: The ticket_number of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._ticket_number

    @ticket_number.setter
    def ticket_number(self, ticket_number):
        """
        Sets the ticket_number of this Ptsv2paymentsTravelInformationTransitAirline.
        Ticket number. Format: English characters only. Restricted string data type that indicates a sequence of letters, numbers, and spaces; special characters are not included. Optional request field. 

        :param ticket_number: The ticket_number of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if ticket_number is not None and len(ticket_number) > 15:
            raise ValueError("Invalid value for `ticket_number`, length must be less than or equal to `15`")

        self._ticket_number = ticket_number

    @property
    def check_digit(self):
        """
        Gets the check_digit of this Ptsv2paymentsTravelInformationTransitAirline.
        Check digit for the ticket number. CyberSource recommends that you validate the check digit. With Discover and Diners Club, a valid ticket number has these characteristics: - The value is numeric. - The first three digits are a valid IATA2 license plate carrier code. - The last digit is a check digit or zero (0). - All remaining digits are nonzero. 

        :return: The check_digit of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._check_digit

    @check_digit.setter
    def check_digit(self, check_digit):
        """
        Sets the check_digit of this Ptsv2paymentsTravelInformationTransitAirline.
        Check digit for the ticket number. CyberSource recommends that you validate the check digit. With Discover and Diners Club, a valid ticket number has these characteristics: - The value is numeric. - The first three digits are a valid IATA2 license plate carrier code. - The last digit is a check digit or zero (0). - All remaining digits are nonzero. 

        :param check_digit: The check_digit of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if check_digit is not None and len(check_digit) > 1:
            raise ValueError("Invalid value for `check_digit`, length must be less than or equal to `1`")

        self._check_digit = check_digit

    @property
    def restricted_ticket_indicator(self):
        """
        Gets the restricted_ticket_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        Flag that indicates whether or not the ticket is restricted (nonrefundable). Possible values: - 0: No restriction (refundable) - 1: Restricted (nonrefundable) Format: English characters only. Restricted string data type that indicates a sequence of letters, numbers, and spaces; special characters are not included. Optional request field. 

        :return: The restricted_ticket_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: int
        """
        return self._restricted_ticket_indicator

    @restricted_ticket_indicator.setter
    def restricted_ticket_indicator(self, restricted_ticket_indicator):
        """
        Sets the restricted_ticket_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        Flag that indicates whether or not the ticket is restricted (nonrefundable). Possible values: - 0: No restriction (refundable) - 1: Restricted (nonrefundable) Format: English characters only. Restricted string data type that indicates a sequence of letters, numbers, and spaces; special characters are not included. Optional request field. 

        :param restricted_ticket_indicator: The restricted_ticket_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: int
        """

        self._restricted_ticket_indicator = restricted_ticket_indicator

    @property
    def transaction_type(self):
        """
        Gets the transaction_type of this Ptsv2paymentsTravelInformationTransitAirline.
        Type of charge. Possible values: - 01: Charge is for an airline ticket - 02: Charge is for an item that is not an airline ticket 

        :return: The transaction_type of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: int
        """
        return self._transaction_type

    @transaction_type.setter
    def transaction_type(self, transaction_type):
        """
        Sets the transaction_type of this Ptsv2paymentsTravelInformationTransitAirline.
        Type of charge. Possible values: - 01: Charge is for an airline ticket - 02: Charge is for an item that is not an airline ticket 

        :param transaction_type: The transaction_type of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: int
        """

        self._transaction_type = transaction_type

    @property
    def extended_payment_code(self):
        """
        Gets the extended_payment_code of this Ptsv2paymentsTravelInformationTransitAirline.
        The field is not currently supported. 

        :return: The extended_payment_code of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._extended_payment_code

    @extended_payment_code.setter
    def extended_payment_code(self, extended_payment_code):
        """
        Sets the extended_payment_code of this Ptsv2paymentsTravelInformationTransitAirline.
        The field is not currently supported. 

        :param extended_payment_code: The extended_payment_code of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if extended_payment_code is not None and len(extended_payment_code) > 3:
            raise ValueError("Invalid value for `extended_payment_code`, length must be less than or equal to `3`")

        self._extended_payment_code = extended_payment_code

    @property
    def passenger_name(self):
        """
        Gets the passenger_name of this Ptsv2paymentsTravelInformationTransitAirline.
        Name of the passenger to whom the ticket was issued.  This will always be a single passenger's name. If there are more than one passengers, provide only the primary passenger's name. Do not include special characters such as commas, hyphens, or apostrophes. Only ASCII characters are supported. Format: English characters only. Optional request field. 

        :return: The passenger_name of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._passenger_name

    @passenger_name.setter
    def passenger_name(self, passenger_name):
        """
        Sets the passenger_name of this Ptsv2paymentsTravelInformationTransitAirline.
        Name of the passenger to whom the ticket was issued.  This will always be a single passenger's name. If there are more than one passengers, provide only the primary passenger's name. Do not include special characters such as commas, hyphens, or apostrophes. Only ASCII characters are supported. Format: English characters only. Optional request field. 

        :param passenger_name: The passenger_name of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if passenger_name is not None and len(passenger_name) > 42:
            raise ValueError("Invalid value for `passenger_name`, length must be less than or equal to `42`")

        self._passenger_name = passenger_name

    @property
    def customer_code(self):
        """
        Gets the customer_code of this Ptsv2paymentsTravelInformationTransitAirline.
        Reference number or code that identifies the cardholder. Format: English characters only. Restricted string data type that indicates a sequence of letters, numbers, and spaces; special characters are not included. Optional request field. 

        :return: The customer_code of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._customer_code

    @customer_code.setter
    def customer_code(self, customer_code):
        """
        Sets the customer_code of this Ptsv2paymentsTravelInformationTransitAirline.
        Reference number or code that identifies the cardholder. Format: English characters only. Restricted string data type that indicates a sequence of letters, numbers, and spaces; special characters are not included. Optional request field. 

        :param customer_code: The customer_code of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if customer_code is not None and len(customer_code) > 40:
            raise ValueError("Invalid value for `customer_code`, length must be less than or equal to `40`")

        self._customer_code = customer_code

    @property
    def document_type(self):
        """
        Gets the document_type of this Ptsv2paymentsTravelInformationTransitAirline.
        Airline document type code that specifies the purpose of the transaction. Format: English characters only. Optional request field.  | Code | Description | | --- | --- | | 01 | Passenger ticket | | 02 | Additional collection | | 03 | Excess baggage | | 04 | Miscellaneous charge order (MCO) or prepaid ticket authorization | | 05 | Special service ticket | | 06 | Supported refund | | 07 | Unsupported refund | | 08 | Lost ticket application | | 09 | Tour order voucher | | 10 | Ticket by mail | | 11 | Undercharge adjustment | | 12 | Group ticket | | 13 | Exchange adjustment | | 14 | SPD or air freight | | 15 | In-flight adjustment | | 16 | Agency passenger ticket | | 17 | Agency tour order or voucher | | 18 | Agency miscellaneous charge order (MCO) | | 19 | Agency exchange order | | 20 | Agency group ticket | | 21 | Debit adjustment for duplicate refund or use | | 22 | In-flight merchandise order | | 23 | Catalogue merchandise order | | 24 | In-flight phone charges | | 25 | Frequent flyer fee or purchase | | 26 | Kennel charge | | 27 | Animal transportation charge | | 28 | Firearms case | | 29 | Upgrade charge | | 30 | Credit for unused transportation | | 31 | Credit for class of service adjustment | | 32 | Credit for denied boarding | | 33 | Credit for miscellaneous refund | | 34 | Credit for lost ticket refund | | 35 | Credit for exchange refund | | 36 | Credit for overcharge adjustment | | 37 | Credit for multiple Unused tickets | | 38 | Exchange order | | 39 | Self-service ticket | | 41 | In-flight duty-free purchase | | 42 | Senior citizen discount booklets | | 43 | Club membership fee | | 44 | Coupon book | | 45 | In-flight charges | | 46 | Tour deposit | | 47 | Frequent flyer overnight delivery charge | | 48 | Frequent flyer fulfillment | | 49 | Small package delivery | | 50 | Vendor sale | | 51 | Miscellaneous taxes or fees | | 52 | Travel agency fee | | 60 | Vendor refund or credit | | 64 | Duty free sale | | 65 | Preferred seat upgrade | | 66 | Cabin upgrade | | 67 | Lounge or club access or day pass | | 68 | Agent assisted reservation or ticketing fee | | 69 | Ticket change or cancel fee | | 70 | Trip insurance | | 71 | Unaccompanied minor | | 72 | Standby fee | | 73 | Curbside baggage | | 74 | In-flight medical equipment | | 75 | Ticket or pass print fee | | 76 | Checked sporting or special equipment | | 77 | Dry ice fee | | 78 | Mail or postage fee | | 79 | Club membership fee or temporary trial | | 80 | Frequent flyer activation or reinstatement | | 81 | Gift certificate | | 82 | Onboard or in-flight prepaid voucher | | 83 | Optional services fee | | 84 | Advance purchase for excess baggage | | 85 | Advance purchase for preferred seat upgrade | | 86 | Advance purchase for cabin upgrade | | 87 | Advance purchase for optional services | | 88 | WiFi | | 89 | Packages | | 90 | In-flight entertainment or internet access | | 91 | Overweight bag fee | | 92 | Sleep sets | | 93 | Special purchase fee | 

        :return: The document_type of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._document_type

    @document_type.setter
    def document_type(self, document_type):
        """
        Sets the document_type of this Ptsv2paymentsTravelInformationTransitAirline.
        Airline document type code that specifies the purpose of the transaction. Format: English characters only. Optional request field.  | Code | Description | | --- | --- | | 01 | Passenger ticket | | 02 | Additional collection | | 03 | Excess baggage | | 04 | Miscellaneous charge order (MCO) or prepaid ticket authorization | | 05 | Special service ticket | | 06 | Supported refund | | 07 | Unsupported refund | | 08 | Lost ticket application | | 09 | Tour order voucher | | 10 | Ticket by mail | | 11 | Undercharge adjustment | | 12 | Group ticket | | 13 | Exchange adjustment | | 14 | SPD or air freight | | 15 | In-flight adjustment | | 16 | Agency passenger ticket | | 17 | Agency tour order or voucher | | 18 | Agency miscellaneous charge order (MCO) | | 19 | Agency exchange order | | 20 | Agency group ticket | | 21 | Debit adjustment for duplicate refund or use | | 22 | In-flight merchandise order | | 23 | Catalogue merchandise order | | 24 | In-flight phone charges | | 25 | Frequent flyer fee or purchase | | 26 | Kennel charge | | 27 | Animal transportation charge | | 28 | Firearms case | | 29 | Upgrade charge | | 30 | Credit for unused transportation | | 31 | Credit for class of service adjustment | | 32 | Credit for denied boarding | | 33 | Credit for miscellaneous refund | | 34 | Credit for lost ticket refund | | 35 | Credit for exchange refund | | 36 | Credit for overcharge adjustment | | 37 | Credit for multiple Unused tickets | | 38 | Exchange order | | 39 | Self-service ticket | | 41 | In-flight duty-free purchase | | 42 | Senior citizen discount booklets | | 43 | Club membership fee | | 44 | Coupon book | | 45 | In-flight charges | | 46 | Tour deposit | | 47 | Frequent flyer overnight delivery charge | | 48 | Frequent flyer fulfillment | | 49 | Small package delivery | | 50 | Vendor sale | | 51 | Miscellaneous taxes or fees | | 52 | Travel agency fee | | 60 | Vendor refund or credit | | 64 | Duty free sale | | 65 | Preferred seat upgrade | | 66 | Cabin upgrade | | 67 | Lounge or club access or day pass | | 68 | Agent assisted reservation or ticketing fee | | 69 | Ticket change or cancel fee | | 70 | Trip insurance | | 71 | Unaccompanied minor | | 72 | Standby fee | | 73 | Curbside baggage | | 74 | In-flight medical equipment | | 75 | Ticket or pass print fee | | 76 | Checked sporting or special equipment | | 77 | Dry ice fee | | 78 | Mail or postage fee | | 79 | Club membership fee or temporary trial | | 80 | Frequent flyer activation or reinstatement | | 81 | Gift certificate | | 82 | Onboard or in-flight prepaid voucher | | 83 | Optional services fee | | 84 | Advance purchase for excess baggage | | 85 | Advance purchase for preferred seat upgrade | | 86 | Advance purchase for cabin upgrade | | 87 | Advance purchase for optional services | | 88 | WiFi | | 89 | Packages | | 90 | In-flight entertainment or internet access | | 91 | Overweight bag fee | | 92 | Sleep sets | | 93 | Special purchase fee | 

        :param document_type: The document_type of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if document_type is not None and len(document_type) > 1:
            raise ValueError("Invalid value for `document_type`, length must be less than or equal to `1`")

        self._document_type = document_type

    @property
    def document_number(self):
        """
        Gets the document_number of this Ptsv2paymentsTravelInformationTransitAirline.
        The field is not currently supported. 

        :return: The document_number of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._document_number

    @document_number.setter
    def document_number(self, document_number):
        """
        Sets the document_number of this Ptsv2paymentsTravelInformationTransitAirline.
        The field is not currently supported. 

        :param document_number: The document_number of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if document_number is not None and len(document_number) > 14:
            raise ValueError("Invalid value for `document_number`, length must be less than or equal to `14`")

        self._document_number = document_number

    @property
    def document_number_of_parts(self):
        """
        Gets the document_number_of_parts of this Ptsv2paymentsTravelInformationTransitAirline.
        The field is not currently supported. 

        :return: The document_number_of_parts of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: int
        """
        return self._document_number_of_parts

    @document_number_of_parts.setter
    def document_number_of_parts(self, document_number_of_parts):
        """
        Sets the document_number_of_parts of this Ptsv2paymentsTravelInformationTransitAirline.
        The field is not currently supported. 

        :param document_number_of_parts: The document_number_of_parts of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: int
        """

        self._document_number_of_parts = document_number_of_parts

    @property
    def invoice_number(self):
        """
        Gets the invoice_number of this Ptsv2paymentsTravelInformationTransitAirline.
        Invoice number for the airline transaction. 

        :return: The invoice_number of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._invoice_number

    @invoice_number.setter
    def invoice_number(self, invoice_number):
        """
        Sets the invoice_number of this Ptsv2paymentsTravelInformationTransitAirline.
        Invoice number for the airline transaction. 

        :param invoice_number: The invoice_number of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if invoice_number is not None and len(invoice_number) > 25:
            raise ValueError("Invalid value for `invoice_number`, length must be less than or equal to `25`")

        self._invoice_number = invoice_number

    @property
    def invoice_date(self):
        """
        Gets the invoice_date of this Ptsv2paymentsTravelInformationTransitAirline.
        Invoice date. The format is YYYYMMDD. If this value is included in the request, it is used in the creation of the invoice number. See \"Invoice Number,\" 

        :return: The invoice_date of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: int
        """
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, invoice_date):
        """
        Sets the invoice_date of this Ptsv2paymentsTravelInformationTransitAirline.
        Invoice date. The format is YYYYMMDD. If this value is included in the request, it is used in the creation of the invoice number. See \"Invoice Number,\" 

        :param invoice_date: The invoice_date of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: int
        """

        self._invoice_date = invoice_date

    @property
    def additional_charges(self):
        """
        Gets the additional_charges of this Ptsv2paymentsTravelInformationTransitAirline.
        Description of the charge if the charge does not involve an airline ticket. For example: Excess baggage. 

        :return: The additional_charges of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._additional_charges

    @additional_charges.setter
    def additional_charges(self, additional_charges):
        """
        Sets the additional_charges of this Ptsv2paymentsTravelInformationTransitAirline.
        Description of the charge if the charge does not involve an airline ticket. For example: Excess baggage. 

        :param additional_charges: The additional_charges of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if additional_charges is not None and len(additional_charges) > 20:
            raise ValueError("Invalid value for `additional_charges`, length must be less than or equal to `20`")

        self._additional_charges = additional_charges

    @property
    def total_fee_amount(self):
        """
        Gets the total_fee_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        Total fee for the ticket. This value cannot exceed `99999999999999999999` (twenty 9s). Format: English characters only. Optional request field. 

        :return: The total_fee_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._total_fee_amount

    @total_fee_amount.setter
    def total_fee_amount(self, total_fee_amount):
        """
        Sets the total_fee_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        Total fee for the ticket. This value cannot exceed `99999999999999999999` (twenty 9s). Format: English characters only. Optional request field. 

        :param total_fee_amount: The total_fee_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if total_fee_amount is not None and len(total_fee_amount) > 12:
            raise ValueError("Invalid value for `total_fee_amount`, length must be less than or equal to `12`")

        self._total_fee_amount = total_fee_amount

    @property
    def clearing_sequence(self):
        """
        Gets the clearing_sequence of this Ptsv2paymentsTravelInformationTransitAirline.
        Number that identifies the clearing message when multiple clearing messages are allowed per authorized transaction. Each clearing message linked to one authorization request must include a unique clearing sequence number between 1 and the total number of clearing records. Format: English characters only. Optional request field. 

        :return: The clearing_sequence of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._clearing_sequence

    @clearing_sequence.setter
    def clearing_sequence(self, clearing_sequence):
        """
        Sets the clearing_sequence of this Ptsv2paymentsTravelInformationTransitAirline.
        Number that identifies the clearing message when multiple clearing messages are allowed per authorized transaction. Each clearing message linked to one authorization request must include a unique clearing sequence number between 1 and the total number of clearing records. Format: English characters only. Optional request field. 

        :param clearing_sequence: The clearing_sequence of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if clearing_sequence is not None and len(clearing_sequence) > 2:
            raise ValueError("Invalid value for `clearing_sequence`, length must be less than or equal to `2`")

        self._clearing_sequence = clearing_sequence

    @property
    def clearing_count(self):
        """
        Gets the clearing_count of this Ptsv2paymentsTravelInformationTransitAirline.
        Total number of clearing messages associated with the authorization request. Format: English characters only. Optional request field. 

        :return: The clearing_count of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._clearing_count

    @clearing_count.setter
    def clearing_count(self, clearing_count):
        """
        Sets the clearing_count of this Ptsv2paymentsTravelInformationTransitAirline.
        Total number of clearing messages associated with the authorization request. Format: English characters only. Optional request field. 

        :param clearing_count: The clearing_count of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if clearing_count is not None and len(clearing_count) > 2:
            raise ValueError("Invalid value for `clearing_count`, length must be less than or equal to `2`")

        self._clearing_count = clearing_count

    @property
    def total_clearing_amount(self):
        """
        Gets the total_clearing_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        Total clearing amount for all transactions in the clearing count set. This value cannot exceed `99999999999999999999` (twenty 9s). Format: English characters only. If this field is not set and if the total amount from the original authorization is not NULL, the total clearing amount is set to the total amount from the original authorization. 

        :return: The total_clearing_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._total_clearing_amount

    @total_clearing_amount.setter
    def total_clearing_amount(self, total_clearing_amount):
        """
        Sets the total_clearing_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        Total clearing amount for all transactions in the clearing count set. This value cannot exceed `99999999999999999999` (twenty 9s). Format: English characters only. If this field is not set and if the total amount from the original authorization is not NULL, the total clearing amount is set to the total amount from the original authorization. 

        :param total_clearing_amount: The total_clearing_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if total_clearing_amount is not None and len(total_clearing_amount) > 20:
            raise ValueError("Invalid value for `total_clearing_amount`, length must be less than or equal to `20`")

        self._total_clearing_amount = total_clearing_amount

    @property
    def number_of_passengers(self):
        """
        Gets the number_of_passengers of this Ptsv2paymentsTravelInformationTransitAirline.
        Number of passengers for whom the ticket was issued. Format: English characters only. Optional request field. 

        :return: The number_of_passengers of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: int
        """
        return self._number_of_passengers

    @number_of_passengers.setter
    def number_of_passengers(self, number_of_passengers):
        """
        Sets the number_of_passengers of this Ptsv2paymentsTravelInformationTransitAirline.
        Number of passengers for whom the ticket was issued. Format: English characters only. Optional request field. 

        :param number_of_passengers: The number_of_passengers of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: int
        """

        self._number_of_passengers = number_of_passengers

    @property
    def reservation_system_code(self):
        """
        Gets the reservation_system_code of this Ptsv2paymentsTravelInformationTransitAirline.
        Code that specifies the computerized reservation system used to make the reservation and purchase the ticket. Format: English characters only. Restricted string data type that indicates a sequence of letters, numbers, and spaces; special characters are not included. Optional request field. 

        :return: The reservation_system_code of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._reservation_system_code

    @reservation_system_code.setter
    def reservation_system_code(self, reservation_system_code):
        """
        Sets the reservation_system_code of this Ptsv2paymentsTravelInformationTransitAirline.
        Code that specifies the computerized reservation system used to make the reservation and purchase the ticket. Format: English characters only. Restricted string data type that indicates a sequence of letters, numbers, and spaces; special characters are not included. Optional request field. 

        :param reservation_system_code: The reservation_system_code of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if reservation_system_code is not None and len(reservation_system_code) > 4:
            raise ValueError("Invalid value for `reservation_system_code`, length must be less than or equal to `4`")

        self._reservation_system_code = reservation_system_code

    @property
    def process_identifier(self):
        """
        Gets the process_identifier of this Ptsv2paymentsTravelInformationTransitAirline.
        Airline process identifier. This value is the airline’s three-digit IATA1 code which is used to process extended payment airline tickets. 

        :return: The process_identifier of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._process_identifier

    @process_identifier.setter
    def process_identifier(self, process_identifier):
        """
        Sets the process_identifier of this Ptsv2paymentsTravelInformationTransitAirline.
        Airline process identifier. This value is the airline’s three-digit IATA1 code which is used to process extended payment airline tickets. 

        :param process_identifier: The process_identifier of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if process_identifier is not None and len(process_identifier) > 3:
            raise ValueError("Invalid value for `process_identifier`, length must be less than or equal to `3`")

        self._process_identifier = process_identifier

    @property
    def ticket_issue_date(self):
        """
        Gets the ticket_issue_date of this Ptsv2paymentsTravelInformationTransitAirline.
        Date on which the transaction occurred. Format: `YYYYMMDD` Format: English characters only. Optional request field. 

        :return: The ticket_issue_date of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._ticket_issue_date

    @ticket_issue_date.setter
    def ticket_issue_date(self, ticket_issue_date):
        """
        Sets the ticket_issue_date of this Ptsv2paymentsTravelInformationTransitAirline.
        Date on which the transaction occurred. Format: `YYYYMMDD` Format: English characters only. Optional request field. 

        :param ticket_issue_date: The ticket_issue_date of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if ticket_issue_date is not None and len(ticket_issue_date) > 8:
            raise ValueError("Invalid value for `ticket_issue_date`, length must be less than or equal to `8`")

        self._ticket_issue_date = ticket_issue_date

    @property
    def electronic_ticket_indicator(self):
        """
        Gets the electronic_ticket_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        Flag that indicates whether an electronic ticket was issued. Possible values: - `true` - `false` Optional request field. 

        :return: The electronic_ticket_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: bool
        """
        return self._electronic_ticket_indicator

    @electronic_ticket_indicator.setter
    def electronic_ticket_indicator(self, electronic_ticket_indicator):
        """
        Sets the electronic_ticket_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        Flag that indicates whether an electronic ticket was issued. Possible values: - `true` - `false` Optional request field. 

        :param electronic_ticket_indicator: The electronic_ticket_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: bool
        """

        self._electronic_ticket_indicator = electronic_ticket_indicator

    @property
    def original_ticket_number(self):
        """
        Gets the original_ticket_number of this Ptsv2paymentsTravelInformationTransitAirline.
        Original ticket number when the transaction is for a replacement ticket. 

        :return: The original_ticket_number of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._original_ticket_number

    @original_ticket_number.setter
    def original_ticket_number(self, original_ticket_number):
        """
        Sets the original_ticket_number of this Ptsv2paymentsTravelInformationTransitAirline.
        Original ticket number when the transaction is for a replacement ticket. 

        :param original_ticket_number: The original_ticket_number of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if original_ticket_number is not None and len(original_ticket_number) > 14:
            raise ValueError("Invalid value for `original_ticket_number`, length must be less than or equal to `14`")

        self._original_ticket_number = original_ticket_number

    @property
    def purchase_type(self):
        """
        Gets the purchase_type of this Ptsv2paymentsTravelInformationTransitAirline.
        Type of purchase. Possible values: - `EXC`: Exchange ticket - `MSC`: Miscellaneous (not a ticket purchase and not a transaction related to an exchange ticket) - `REF`: Refund - `TKT`: Ticket Format: English characters only. Optional request field. 

        :return: The purchase_type of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._purchase_type

    @purchase_type.setter
    def purchase_type(self, purchase_type):
        """
        Sets the purchase_type of this Ptsv2paymentsTravelInformationTransitAirline.
        Type of purchase. Possible values: - `EXC`: Exchange ticket - `MSC`: Miscellaneous (not a ticket purchase and not a transaction related to an exchange ticket) - `REF`: Refund - `TKT`: Ticket Format: English characters only. Optional request field. 

        :param purchase_type: The purchase_type of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if purchase_type is not None and len(purchase_type) > 3:
            raise ValueError("Invalid value for `purchase_type`, length must be less than or equal to `3`")

        self._purchase_type = purchase_type

    @property
    def credit_reason_indicator(self):
        """
        Gets the credit_reason_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        Reason for the credit. Possible values: - `A`: Cancellation of the ancillary passenger transport purchase. - `B`: Cancellation of the airline ticket and the passenger transport ancillary purchase. - `C`: Cancellation of the airline ticket. - `O`: Other. - `P`: Partial refund of the airline ticket. Format: English characters only.  Optional request field. 

        :return: The credit_reason_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._credit_reason_indicator

    @credit_reason_indicator.setter
    def credit_reason_indicator(self, credit_reason_indicator):
        """
        Sets the credit_reason_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        Reason for the credit. Possible values: - `A`: Cancellation of the ancillary passenger transport purchase. - `B`: Cancellation of the airline ticket and the passenger transport ancillary purchase. - `C`: Cancellation of the airline ticket. - `O`: Other. - `P`: Partial refund of the airline ticket. Format: English characters only.  Optional request field. 

        :param credit_reason_indicator: The credit_reason_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if credit_reason_indicator is not None and len(credit_reason_indicator) > 1:
            raise ValueError("Invalid value for `credit_reason_indicator`, length must be less than or equal to `1`")

        self._credit_reason_indicator = credit_reason_indicator

    @property
    def ticket_change_indicator(self):
        """
        Gets the ticket_change_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        Type of update. Possible values: - `C`: Change to the existing ticket. - `N`: New ticket. Format: English characters only Optional request field. 

        :return: The ticket_change_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._ticket_change_indicator

    @ticket_change_indicator.setter
    def ticket_change_indicator(self, ticket_change_indicator):
        """
        Sets the ticket_change_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        Type of update. Possible values: - `C`: Change to the existing ticket. - `N`: New ticket. Format: English characters only Optional request field. 

        :param ticket_change_indicator: The ticket_change_indicator of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if ticket_change_indicator is not None and len(ticket_change_indicator) > 1:
            raise ValueError("Invalid value for `ticket_change_indicator`, length must be less than or equal to `1`")

        self._ticket_change_indicator = ticket_change_indicator

    @property
    def plan_number(self):
        """
        Gets the plan_number of this Ptsv2paymentsTravelInformationTransitAirline.
        Plan number based on the fare. This value is provided by the airline. Format: English characters only. Optional request field. 

        :return: The plan_number of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._plan_number

    @plan_number.setter
    def plan_number(self, plan_number):
        """
        Sets the plan_number of this Ptsv2paymentsTravelInformationTransitAirline.
        Plan number based on the fare. This value is provided by the airline. Format: English characters only. Optional request field. 

        :param plan_number: The plan_number of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if plan_number is not None and len(plan_number) > 1:
            raise ValueError("Invalid value for `plan_number`, length must be less than or equal to `1`")

        self._plan_number = plan_number

    @property
    def arrival_date(self):
        """
        Gets the arrival_date of this Ptsv2paymentsTravelInformationTransitAirline.
        Date of arrival for the last leg of the trip. Format: `MMDDYYYY` English characters only. Optional request field. 

        :return: The arrival_date of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._arrival_date

    @arrival_date.setter
    def arrival_date(self, arrival_date):
        """
        Sets the arrival_date of this Ptsv2paymentsTravelInformationTransitAirline.
        Date of arrival for the last leg of the trip. Format: `MMDDYYYY` English characters only. Optional request field. 

        :param arrival_date: The arrival_date of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if arrival_date is not None and len(arrival_date) > 8:
            raise ValueError("Invalid value for `arrival_date`, length must be less than or equal to `8`")

        self._arrival_date = arrival_date

    @property
    def restricted_ticket_desciption(self):
        """
        Gets the restricted_ticket_desciption of this Ptsv2paymentsTravelInformationTransitAirline.
        Text that describes the ticket limitations, such as _nonrefundable_. Format: English characters only. Optional request field. 

        :return: The restricted_ticket_desciption of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._restricted_ticket_desciption

    @restricted_ticket_desciption.setter
    def restricted_ticket_desciption(self, restricted_ticket_desciption):
        """
        Sets the restricted_ticket_desciption of this Ptsv2paymentsTravelInformationTransitAirline.
        Text that describes the ticket limitations, such as _nonrefundable_. Format: English characters only. Optional request field. 

        :param restricted_ticket_desciption: The restricted_ticket_desciption of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if restricted_ticket_desciption is not None and len(restricted_ticket_desciption) > 20:
            raise ValueError("Invalid value for `restricted_ticket_desciption`, length must be less than or equal to `20`")

        self._restricted_ticket_desciption = restricted_ticket_desciption

    @property
    def exchange_ticket_amount(self):
        """
        Gets the exchange_ticket_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        Amount of the exchanged ticket. Format: English characters only. 

        :return: The exchange_ticket_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._exchange_ticket_amount

    @exchange_ticket_amount.setter
    def exchange_ticket_amount(self, exchange_ticket_amount):
        """
        Sets the exchange_ticket_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        Amount of the exchanged ticket. Format: English characters only. 

        :param exchange_ticket_amount: The exchange_ticket_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if exchange_ticket_amount is not None and len(exchange_ticket_amount) > 12:
            raise ValueError("Invalid value for `exchange_ticket_amount`, length must be less than or equal to `12`")

        self._exchange_ticket_amount = exchange_ticket_amount

    @property
    def exchange_ticket_fee_amount(self):
        """
        Gets the exchange_ticket_fee_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        Fee for exchanging the ticket. Format: English characters only. Optional request field. 

        :return: The exchange_ticket_fee_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._exchange_ticket_fee_amount

    @exchange_ticket_fee_amount.setter
    def exchange_ticket_fee_amount(self, exchange_ticket_fee_amount):
        """
        Sets the exchange_ticket_fee_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        Fee for exchanging the ticket. Format: English characters only. Optional request field. 

        :param exchange_ticket_fee_amount: The exchange_ticket_fee_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if exchange_ticket_fee_amount is not None and len(exchange_ticket_fee_amount) > 12:
            raise ValueError("Invalid value for `exchange_ticket_fee_amount`, length must be less than or equal to `12`")

        self._exchange_ticket_fee_amount = exchange_ticket_fee_amount

    @property
    def reservation_type(self):
        """
        Gets the reservation_type of this Ptsv2paymentsTravelInformationTransitAirline.
        The field is not currently supported. 

        :return: The reservation_type of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._reservation_type

    @reservation_type.setter
    def reservation_type(self, reservation_type):
        """
        Sets the reservation_type of this Ptsv2paymentsTravelInformationTransitAirline.
        The field is not currently supported. 

        :param reservation_type: The reservation_type of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if reservation_type is not None and len(reservation_type) > 32:
            raise ValueError("Invalid value for `reservation_type`, length must be less than or equal to `32`")

        self._reservation_type = reservation_type

    @property
    def boarding_fee_amount(self):
        """
        Gets the boarding_fee_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        Boarding fee. 

        :return: The boarding_fee_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: str
        """
        return self._boarding_fee_amount

    @boarding_fee_amount.setter
    def boarding_fee_amount(self, boarding_fee_amount):
        """
        Sets the boarding_fee_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        Boarding fee. 

        :param boarding_fee_amount: The boarding_fee_amount of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: str
        """
        if boarding_fee_amount is not None and len(boarding_fee_amount) > 12:
            raise ValueError("Invalid value for `boarding_fee_amount`, length must be less than or equal to `12`")

        self._boarding_fee_amount = boarding_fee_amount

    @property
    def legs(self):
        """
        Gets the legs of this Ptsv2paymentsTravelInformationTransitAirline.

        :return: The legs of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: list[Ptsv2paymentsTravelInformationTransitAirlineLegs]
        """
        return self._legs

    @legs.setter
    def legs(self, legs):
        """
        Sets the legs of this Ptsv2paymentsTravelInformationTransitAirline.

        :param legs: The legs of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: list[Ptsv2paymentsTravelInformationTransitAirlineLegs]
        """

        self._legs = legs

    @property
    def ancillary_information(self):
        """
        Gets the ancillary_information of this Ptsv2paymentsTravelInformationTransitAirline.

        :return: The ancillary_information of this Ptsv2paymentsTravelInformationTransitAirline.
        :rtype: Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation
        """
        return self._ancillary_information

    @ancillary_information.setter
    def ancillary_information(self, ancillary_information):
        """
        Sets the ancillary_information of this Ptsv2paymentsTravelInformationTransitAirline.

        :param ancillary_information: The ancillary_information of this Ptsv2paymentsTravelInformationTransitAirline.
        :type: Ptsv2paymentsTravelInformationTransitAirlineAncillaryInformation
        """

        self._ancillary_information = ancillary_information

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2paymentsTravelInformationTransitAirline):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Vasv2taxOrderInformationOrderOrigin(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'locality': 'str',
        'administrative_area': 'str',
        'postal_code': 'str',
        'country': 'str'
    }

    attribute_map = {
        'locality': 'locality',
        'administrative_area': 'administrativeArea',
        'postal_code': 'postalCode',
        'country': 'country'
    }

    def __init__(self, locality=None, administrative_area=None, postal_code=None, country=None):
        """
        Vasv2taxOrderInformationOrderOrigin - a model defined in Swagger
        """

        self._locality = None
        self._administrative_area = None
        self._postal_code = None
        self._country = None

        if locality is not None:
          self.locality = locality
        if administrative_area is not None:
          self.administrative_area = administrative_area
        if postal_code is not None:
          self.postal_code = postal_code
        if country is not None:
          self.country = country

    @property
    def locality(self):
        """
        Gets the locality of this Vasv2taxOrderInformationOrderOrigin.
        Order origin city. This field is not used unless the `orderInformation.orderOrigin.administrativeArea` and `orderInformation.orderOrigin.country` fields are present.  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. The location of the buyer at the time of placing the order. 

        :return: The locality of this Vasv2taxOrderInformationOrderOrigin.
        :rtype: str
        """
        return self._locality

    @locality.setter
    def locality(self, locality):
        """
        Sets the locality of this Vasv2taxOrderInformationOrderOrigin.
        Order origin city. This field is not used unless the `orderInformation.orderOrigin.administrativeArea` and `orderInformation.orderOrigin.country` fields are present.  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. The location of the buyer at the time of placing the order. 

        :param locality: The locality of this Vasv2taxOrderInformationOrderOrigin.
        :type: str
        """
        if locality is not None and len(locality) > 50:
            raise ValueError("Invalid value for `locality`, length must be less than or equal to `50`")

        self._locality = locality

    @property
    def administrative_area(self):
        """
        Gets the administrative_area of this Vasv2taxOrderInformationOrderOrigin.
        Order origin state. This field is not used unless the `orderInformation.orderOrigin.locality` and `orderInformation.orderOrigin.country` fields are present. Use the [State, Province, and Territory Codes for the United States and Canada](http://apps.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. The location of the buyer at the time of placing the order. 

        :return: The administrative_area of this Vasv2taxOrderInformationOrderOrigin.
        :rtype: str
        """
        return self._administrative_area

    @administrative_area.setter
    def administrative_area(self, administrative_area):
        """
        Sets the administrative_area of this Vasv2taxOrderInformationOrderOrigin.
        Order origin state. This field is not used unless the `orderInformation.orderOrigin.locality` and `orderInformation.orderOrigin.country` fields are present. Use the [State, Province, and Territory Codes for the United States and Canada](http://apps.cybersource.com/library/documentation/sbc/quickref/states_and_provinces.pdf).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. The location of the buyer at the time of placing the order. 

        :param administrative_area: The administrative_area of this Vasv2taxOrderInformationOrderOrigin.
        :type: str
        """
        if administrative_area is not None and len(administrative_area) > 2:
            raise ValueError("Invalid value for `administrative_area`, length must be less than or equal to `2`")

        self._administrative_area = administrative_area

    @property
    def postal_code(self):
        """
        Gets the postal_code of this Vasv2taxOrderInformationOrderOrigin.
        Order origin postal code. This field is not used unless the `orderInformation.orderOrigin.locality`, `orderInformation.orderOrigin.administrativeArea` and `orderInformation.orderOrigin.country` fields are present. Must be sent at the lineItem level to appear in the Tax Detail Report.  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. The location of the buyer at the time of placing the order. 

        :return: The postal_code of this Vasv2taxOrderInformationOrderOrigin.
        :rtype: str
        """
        return self._postal_code

    @postal_code.setter
    def postal_code(self, postal_code):
        """
        Sets the postal_code of this Vasv2taxOrderInformationOrderOrigin.
        Order origin postal code. This field is not used unless the `orderInformation.orderOrigin.locality`, `orderInformation.orderOrigin.administrativeArea` and `orderInformation.orderOrigin.country` fields are present. Must be sent at the lineItem level to appear in the Tax Detail Report.  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. The location of the buyer at the time of placing the order. 

        :param postal_code: The postal_code of this Vasv2taxOrderInformationOrderOrigin.
        :type: str
        """
        if postal_code is not None and len(postal_code) > 10:
            raise ValueError("Invalid value for `postal_code`, length must be less than or equal to `10`")

        self._postal_code = postal_code

    @property
    def country(self):
        """
        Gets the country of this Vasv2taxOrderInformationOrderOrigin.
        Order origin country. This field is not used unless the `orderInformation.orderOrigin.administrativeArea` and `orderInformation.orderOrigin.locality` fields are present. Use the [ISO Standard Country Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. The location of the buyer at the time of placing the order. 

        :return: The country of this Vasv2taxOrderInformationOrderOrigin.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this Vasv2taxOrderInformationOrderOrigin.
        Order origin country. This field is not used unless the `orderInformation.orderOrigin.administrativeArea` and `orderInformation.orderOrigin.locality` fields are present. Use the [ISO Standard Country Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).  **NOTE** If this field appears in a `lineItems` object, then the value of this field in the `lineItems` object overrides the value of the corresponding field at the request-level or order-level object.  #### Tax Calculation Optional field for U.S. and Canadian taxes. Not applicable to international and value added taxes. The location of the buyer at the time of placing the order. 

        :param country: The country of this Vasv2taxOrderInformationOrderOrigin.
        :type: str
        """
        if country is not None and len(country) > 2:
            raise ValueError("Invalid value for `country`, length must be less than or equal to `2`")

        self._country = country

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Vasv2taxOrderInformationOrderOrigin):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'balance_amount': 'str',
        'previous_balance_amount': 'str',
        'currency': 'str'
    }

    attribute_map = {
        'balance_amount': 'balanceAmount',
        'previous_balance_amount': 'previousBalanceAmount',
        'currency': 'currency'
    }

    def __init__(self, balance_amount=None, previous_balance_amount=None, currency=None):
        """
        TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures - a model defined in Swagger
        """

        self._balance_amount = None
        self._previous_balance_amount = None
        self._currency = None

        if balance_amount is not None:
          self.balance_amount = balance_amount
        if previous_balance_amount is not None:
          self.previous_balance_amount = previous_balance_amount
        if currency is not None:
          self.currency = currency

    @property
    def balance_amount(self):
        """
        Gets the balance_amount of this TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures.
        Remaining balance on the account.  Returned by authorization service.  #### PIN debit Remaining balance on the prepaid card.  Returned by PIN debit purchase. 

        :return: The balance_amount of this TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._balance_amount

    @balance_amount.setter
    def balance_amount(self, balance_amount):
        """
        Sets the balance_amount of this TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures.
        Remaining balance on the account.  Returned by authorization service.  #### PIN debit Remaining balance on the prepaid card.  Returned by PIN debit purchase. 

        :param balance_amount: The balance_amount of this TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if balance_amount is not None and len(balance_amount) > 12:
            raise ValueError("Invalid value for `balance_amount`, length must be less than or equal to `12`")

        self._balance_amount = balance_amount

    @property
    def previous_balance_amount(self):
        """
        Gets the previous_balance_amount of this TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures.
        Remaining balance on the account.  Returned by authorization service.  #### PIN debit Remaining balance on the prepaid card.  Returned by PIN debit purchase. 

        :return: The previous_balance_amount of this TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._previous_balance_amount

    @previous_balance_amount.setter
    def previous_balance_amount(self, previous_balance_amount):
        """
        Sets the previous_balance_amount of this TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures.
        Remaining balance on the account.  Returned by authorization service.  #### PIN debit Remaining balance on the prepaid card.  Returned by PIN debit purchase. 

        :param previous_balance_amount: The previous_balance_amount of this TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if previous_balance_amount is not None and len(previous_balance_amount) > 12:
            raise ValueError("Invalid value for `previous_balance_amount`, length must be less than or equal to `12`")

        self._previous_balance_amount = previous_balance_amount

    @property
    def currency(self):
        """
        Gets the currency of this TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures.
        Currency of the remaining balance on the account. For the possible values, see the [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf)  Returned by authorization service.  #### PIN debit Currency of the remaining balance on the prepaid card.  Returned by PIN debit purchase. 

        :return: The currency of this TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures.
        :rtype: str
        """
        return self._currency

    @currency.setter
    def currency(self, currency):
        """
        Sets the currency of this TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures.
        Currency of the remaining balance on the account. For the possible values, see the [ISO Standard Currency Codes.](http://apps.cybersource.com/library/documentation/sbc/quickref/currencies.pdf)  Returned by authorization service.  #### PIN debit Currency of the remaining balance on the prepaid card.  Returned by PIN debit purchase. 

        :param currency: The currency of this TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures.
        :type: str
        """
        if currency is not None and len(currency) > 5:
            raise ValueError("Invalid value for `currency`, length must be less than or equal to `5`")

        self._currency = currency

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsGet200ResponsePaymentInformationAccountFeatures):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Ptsv2creditsInstallmentInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'plan_type': 'str'
    }

    attribute_map = {
        'plan_type': 'planType'
    }

    def __init__(self, plan_type=None):
        """
        Ptsv2creditsInstallmentInformation - a model defined in Swagger
        """

        self._plan_type = None

        if plan_type is not None:
          self.plan_type = plan_type

    @property
    def plan_type(self):
        """
        Gets the plan_type of this Ptsv2creditsInstallmentInformation.
        #### American Express Direct, Cielo, and CyberSource Latin American Processing Flag that indicates the type of funding for the installment plan associated with the payment.  Possible values: - `1`: Merchant-funded installment plan - `2`: Issuer-funded installment plan If you do not include this field in the request, CyberSource uses the value in your CyberSource account.  To change the value in your CyberSource account, contact CyberSource Customer Service. For details, see `installment_plan_type` field description in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### CyberSource through VisaNet and American Express Defined code that indicates the type of installment plan for this transaction.  Contact American Express for: - Information about the kinds of installment plans that American Express provides - Values for this field  For installment payments with American Express in Brazil, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP07 TCR3 - Position: 5-6 - Field: Plan Type  * The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to CyberSource. CyberSource through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment card companies.  #### CyberSource through VisaNet with Visa or Mastercard Flag indicating the type of funding for the installment plan associated with the payment. Possible values: - 1 or 01: Merchant-funded installment plan - 2 or 02: Issuer-funded installment plan - 43: Crediario installment plan—only with Visa in Brazil For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  For installment payments with Visa in Brazil, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP07 TCR1 - Position: 5-6 - Field: Installment Type  For all other kinds of installment payments, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP01 TCR5 - Position: 39-40 - Field: Installment Plan Type (Issuer or Merchant) 

        :return: The plan_type of this Ptsv2creditsInstallmentInformation.
        :rtype: str
        """
        return self._plan_type

    @plan_type.setter
    def plan_type(self, plan_type):
        """
        Sets the plan_type of this Ptsv2creditsInstallmentInformation.
        #### American Express Direct, Cielo, and CyberSource Latin American Processing Flag that indicates the type of funding for the installment plan associated with the payment.  Possible values: - `1`: Merchant-funded installment plan - `2`: Issuer-funded installment plan If you do not include this field in the request, CyberSource uses the value in your CyberSource account.  To change the value in your CyberSource account, contact CyberSource Customer Service. For details, see `installment_plan_type` field description in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  #### CyberSource through VisaNet and American Express Defined code that indicates the type of installment plan for this transaction.  Contact American Express for: - Information about the kinds of installment plans that American Express provides - Values for this field  For installment payments with American Express in Brazil, the value for this field corresponds to the following data in the TC 33 capture file*: - Record: CP07 TCR3 - Position: 5-6 - Field: Plan Type  * The TC 33 Capture file contains information about the purchases and refunds that a merchant submits to CyberSource. CyberSource through VisaNet creates the TC 33 Capture file at the end of the day and sends it to the merchant’s acquirer, who uses this information to facilitate end-of-day clearing processing with payment card companies.  #### CyberSource through VisaNet with Visa or Mastercard Flag indicating the type of funding for the installment plan associated with the payment. Possible values: - 1 or 01: Merchant-funded installment plan - 2 or 02: Issuer-funded installment plan - 43: Crediario installment plan—only with Visa in Brazil For details, see \"Installment Payments on CyberSource through VisaNet\" in the [Credit Card Services Using the SCMP API Guide](https://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html/)  For installment payments with Visa in Brazil, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP07 TCR1 - Position: 5-6 - Field: Installment Type  For all other kinds of installment payments, the value for this field corresponds to the following data in the TC 33 capture file5: - Record: CP01 TCR5 - Position: 39-40 - Field: Installment Plan Type (Issuer or Merchant) 

        :param plan_type: The plan_type of this Ptsv2creditsInstallmentInformation.
        :type: str
        """
        if plan_type is not None and len(plan_type) > 1:
            raise ValueError("Invalid value for `plan_type`, length must be less than or equal to `1`")

        self._plan_type = plan_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Ptsv2creditsInstallmentInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Vasv2taxOrderInformationInvoiceDetails(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'invoice_date': 'str'
    }

    attribute_map = {
        'invoice_date': 'invoiceDate'
    }

    def __init__(self, invoice_date=None):
        """
        Vasv2taxOrderInformationInvoiceDetails - a model defined in Swagger
        """

        self._invoice_date = None

        if invoice_date is not None:
          self.invoice_date = invoice_date

    @property
    def invoice_date(self):
        """
        Gets the invoice_date of this Vasv2taxOrderInformationInvoiceDetails.
        Date of the tax calculation. Use format YYYYMMDD. You can provide a date in the past if you are calculating tax for a refund and want to know what the tax was on the date the order was placed. You can provide a date in the future if you are calculating the tax for a future date, such as an upcoming tax holiday.  The default is the date, in Pacific time, that the bank receives the request. Keep this in mind if you are in a different time zone and want the tax calculated with the rates that are applicable on a specific date.  #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes. 

        :return: The invoice_date of this Vasv2taxOrderInformationInvoiceDetails.
        :rtype: str
        """
        return self._invoice_date

    @invoice_date.setter
    def invoice_date(self, invoice_date):
        """
        Sets the invoice_date of this Vasv2taxOrderInformationInvoiceDetails.
        Date of the tax calculation. Use format YYYYMMDD. You can provide a date in the past if you are calculating tax for a refund and want to know what the tax was on the date the order was placed. You can provide a date in the future if you are calculating the tax for a future date, such as an upcoming tax holiday.  The default is the date, in Pacific time, that the bank receives the request. Keep this in mind if you are in a different time zone and want the tax calculated with the rates that are applicable on a specific date.  #### Tax Calculation Optional field for U.S., Canadian, international tax, and value added taxes. 

        :param invoice_date: The invoice_date of this Vasv2taxOrderInformationInvoiceDetails.
        :type: str
        """
        if invoice_date is not None and len(invoice_date) > 8:
            raise ValueError("Invalid value for `invoice_date`, length must be less than or equal to `8`")

        self._invoice_date = invoice_date

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Vasv2taxOrderInformationInvoiceDetails):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class ReportingV3ReportDefinitionsNameGet200ResponseAttributes(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'id': 'str',
        'name': 'str',
        'description': 'str',
        'filter_type': 'str',
        'default': 'bool',
        'required': 'bool',
        'supported_type': 'str'
    }

    attribute_map = {
        'id': 'id',
        'name': 'name',
        'description': 'description',
        'filter_type': 'filterType',
        'default': 'default',
        'required': 'required',
        'supported_type': 'supportedType'
    }

    def __init__(self, id=None, name=None, description=None, filter_type=None, default=None, required=None, supported_type=None):
        """
        ReportingV3ReportDefinitionsNameGet200ResponseAttributes - a model defined in Swagger
        """

        self._id = None
        self._name = None
        self._description = None
        self._filter_type = None
        self._default = None
        self._required = None
        self._supported_type = None

        if id is not None:
          self.id = id
        if name is not None:
          self.name = name
        if description is not None:
          self.description = description
        if filter_type is not None:
          self.filter_type = filter_type
        if default is not None:
          self.default = default
        if required is not None:
          self.required = required
        if supported_type is not None:
          self.supported_type = supported_type

    @property
    def id(self):
        """
        Gets the id of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.

        :return: The id of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :rtype: str
        """
        return self._id

    @id.setter
    def id(self, id):
        """
        Sets the id of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.

        :param id: The id of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :type: str
        """

        self._id = id

    @property
    def name(self):
        """
        Gets the name of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.

        :return: The name of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """
        Sets the name of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.

        :param name: The name of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :type: str
        """

        self._name = name

    @property
    def description(self):
        """
        Gets the description of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.

        :return: The description of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """
        Sets the description of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.

        :param description: The description of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :type: str
        """

        self._description = description

    @property
    def filter_type(self):
        """
        Gets the filter_type of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        Attribute Filter Type.

        :return: The filter_type of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :rtype: str
        """
        return self._filter_type

    @filter_type.setter
    def filter_type(self, filter_type):
        """
        Sets the filter_type of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        Attribute Filter Type.

        :param filter_type: The filter_type of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :type: str
        """

        self._filter_type = filter_type

    @property
    def default(self):
        """
        Gets the default of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.

        :return: The default of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :rtype: bool
        """
        return self._default

    @default.setter
    def default(self, default):
        """
        Sets the default of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.

        :param default: The default of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :type: bool
        """

        self._default = default

    @property
    def required(self):
        """
        Gets the required of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.

        :return: The required of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :rtype: bool
        """
        return self._required

    @required.setter
    def required(self, required):
        """
        Sets the required of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.

        :param required: The required of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :type: bool
        """

        self._required = required

    @property
    def supported_type(self):
        """
        Gets the supported_type of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        Valid values for the filter.

        :return: The supported_type of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :rtype: str
        """
        return self._supported_type

    @supported_type.setter
    def supported_type(self, supported_type):
        """
        Sets the supported_type of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        Valid values for the filter.

        :param supported_type: The supported_type of this ReportingV3ReportDefinitionsNameGet200ResponseAttributes.
        :type: str
        """

        self._supported_type = supported_type

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, ReportingV3ReportDefinitionsNameGet200ResponseAttributes):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'ip_country_confidence': 'int',
        'info_codes': 'list[str]',
        'watch_list': 'RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchList'
    }

    attribute_map = {
        'ip_country_confidence': 'ipCountryConfidence',
        'info_codes': 'infoCodes',
        'watch_list': 'watchList'
    }

    def __init__(self, ip_country_confidence=None, info_codes=None, watch_list=None):
        """
        RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation - a model defined in Swagger
        """

        self._ip_country_confidence = None
        self._info_codes = None
        self._watch_list = None

        if ip_country_confidence is not None:
          self.ip_country_confidence = ip_country_confidence
        if info_codes is not None:
          self.info_codes = info_codes
        if watch_list is not None:
          self.watch_list = watch_list

    @property
    def ip_country_confidence(self):
        """
        Gets the ip_country_confidence of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation.
        Likelihood that the country associated with the customer’s IP address was identified correctly. Returns a value from 1–100, where 100 indicates the highest likelihood. If the country cannot be determined, the value is –1. 

        :return: The ip_country_confidence of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation.
        :rtype: int
        """
        return self._ip_country_confidence

    @ip_country_confidence.setter
    def ip_country_confidence(self, ip_country_confidence):
        """
        Sets the ip_country_confidence of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation.
        Likelihood that the country associated with the customer’s IP address was identified correctly. Returns a value from 1–100, where 100 indicates the highest likelihood. If the country cannot be determined, the value is –1. 

        :param ip_country_confidence: The ip_country_confidence of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation.
        :type: int
        """
        if ip_country_confidence is not None and ip_country_confidence > 100:
            raise ValueError("Invalid value for `ip_country_confidence`, must be a value less than or equal to `100`")
        if ip_country_confidence is not None and ip_country_confidence < -1:
            raise ValueError("Invalid value for `ip_country_confidence`, must be a value greater than or equal to `-1`")

        self._ip_country_confidence = ip_country_confidence

    @property
    def info_codes(self):
        """
        Gets the info_codes of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation.
        Returned when the Denied Parties List check (first two codes) or the export service (all others) would have declined the transaction. This field can contain one or more of these values: - `MATCH-DPC`: Denied Parties List match. - `UNV-DPC`: Denied Parties List unavailable. - `MATCH-BCO`: Billing country restricted. - `MATCH-EMCO`: Email country restricted. - `MATCH-HCO`: Host name country restricted. - `MATCH-IPCO`: IP country restricted. - `MATCH-SCO`: Shipping country restricted. 

        :return: The info_codes of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation.
        :rtype: list[str]
        """
        return self._info_codes

    @info_codes.setter
    def info_codes(self, info_codes):
        """
        Sets the info_codes of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation.
        Returned when the Denied Parties List check (first two codes) or the export service (all others) would have declined the transaction. This field can contain one or more of these values: - `MATCH-DPC`: Denied Parties List match. - `UNV-DPC`: Denied Parties List unavailable. - `MATCH-BCO`: Billing country restricted. - `MATCH-EMCO`: Email country restricted. - `MATCH-HCO`: Host name country restricted. - `MATCH-IPCO`: IP country restricted. - `MATCH-SCO`: Shipping country restricted. 

        :param info_codes: The info_codes of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation.
        :type: list[str]
        """

        self._info_codes = info_codes

    @property
    def watch_list(self):
        """
        Gets the watch_list of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation.

        :return: The watch_list of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation.
        :rtype: RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchList
        """
        return self._watch_list

    @watch_list.setter
    def watch_list(self, watch_list):
        """
        Sets the watch_list of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation.

        :param watch_list: The watch_list of this RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation.
        :type: RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformationWatchList
        """

        self._watch_list = watch_list

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, RiskV1ExportComplianceInquiriesPost201ResponseExportComplianceInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class Riskv1authenticationresultsConsumerAuthenticationInformation(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'authentication_transaction_id': 'str',
        'authentication_type': 'str',
        'effective_authentication_type': 'str',
        'response_access_token': 'str',
        'signed_pares_status_reason': 'str',
        'signed_pares': 'str',
        'white_list_status': 'str'
    }

    attribute_map = {
        'authentication_transaction_id': 'authenticationTransactionId',
        'authentication_type': 'authenticationType',
        'effective_authentication_type': 'effectiveAuthenticationType',
        'response_access_token': 'responseAccessToken',
        'signed_pares_status_reason': 'signedParesStatusReason',
        'signed_pares': 'signedPares',
        'white_list_status': 'whiteListStatus'
    }

    def __init__(self, authentication_transaction_id=None, authentication_type=None, effective_authentication_type=None, response_access_token=None, signed_pares_status_reason=None, signed_pares=None, white_list_status=None):
        """
        Riskv1authenticationresultsConsumerAuthenticationInformation - a model defined in Swagger
        """

        self._authentication_transaction_id = None
        self._authentication_type = None
        self._effective_authentication_type = None
        self._response_access_token = None
        self._signed_pares_status_reason = None
        self._signed_pares = None
        self._white_list_status = None

        if authentication_transaction_id is not None:
          self.authentication_transaction_id = authentication_transaction_id
        if authentication_type is not None:
          self.authentication_type = authentication_type
        if effective_authentication_type is not None:
          self.effective_authentication_type = effective_authentication_type
        if response_access_token is not None:
          self.response_access_token = response_access_token
        if signed_pares_status_reason is not None:
          self.signed_pares_status_reason = signed_pares_status_reason
        self.signed_pares = signed_pares
        if white_list_status is not None:
          self.white_list_status = white_list_status

    @property
    def authentication_transaction_id(self):
        """
        Gets the authentication_transaction_id of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        Payer authentication transaction identifier passed to link the check enrollment and validate authentication messages. **Note**: Required for Standard integration for enroll service. Required for Hybrid integration for validate service. 

        :return: The authentication_transaction_id of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._authentication_transaction_id

    @authentication_transaction_id.setter
    def authentication_transaction_id(self, authentication_transaction_id):
        """
        Sets the authentication_transaction_id of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        Payer authentication transaction identifier passed to link the check enrollment and validate authentication messages. **Note**: Required for Standard integration for enroll service. Required for Hybrid integration for validate service. 

        :param authentication_transaction_id: The authentication_transaction_id of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :type: str
        """
        if authentication_transaction_id is not None and len(authentication_transaction_id) > 20:
            raise ValueError("Invalid value for `authentication_transaction_id`, length must be less than or equal to `20`")

        self._authentication_transaction_id = authentication_transaction_id

    @property
    def authentication_type(self):
        """
        Gets the authentication_type of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        Indicates the type of authentication that will be used to challenge the card holder.  Possible Values:  01 - Static  02 - Dynamic  03 - OOB (Out of Band)  04 - Decoupled **NOTE**:  EMV 3-D Secure version 2.1.0 supports values 01-03.  Version 2.2.0 supports values 01-04.  Decoupled authentication is not supported at this time. 

        :return: The authentication_type of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._authentication_type

    @authentication_type.setter
    def authentication_type(self, authentication_type):
        """
        Sets the authentication_type of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        Indicates the type of authentication that will be used to challenge the card holder.  Possible Values:  01 - Static  02 - Dynamic  03 - OOB (Out of Band)  04 - Decoupled **NOTE**:  EMV 3-D Secure version 2.1.0 supports values 01-03.  Version 2.2.0 supports values 01-04.  Decoupled authentication is not supported at this time. 

        :param authentication_type: The authentication_type of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :type: str
        """
        if authentication_type is not None and len(authentication_type) > 2:
            raise ValueError("Invalid value for `authentication_type`, length must be less than or equal to `2`")

        self._authentication_type = authentication_type

    @property
    def effective_authentication_type(self):
        """
        Gets the effective_authentication_type of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        This field describes the type of 3DS transaction flow that took place.  It can be one of three possible flows; CH - Challenge FR - Frictionless FD - Frictionless with delegation, (challenge not generated by the issuer but by the scheme on behalf of the issuer). 

        :return: The effective_authentication_type of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._effective_authentication_type

    @effective_authentication_type.setter
    def effective_authentication_type(self, effective_authentication_type):
        """
        Sets the effective_authentication_type of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        This field describes the type of 3DS transaction flow that took place.  It can be one of three possible flows; CH - Challenge FR - Frictionless FD - Frictionless with delegation, (challenge not generated by the issuer but by the scheme on behalf of the issuer). 

        :param effective_authentication_type: The effective_authentication_type of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :type: str
        """
        if effective_authentication_type is not None and len(effective_authentication_type) > 2:
            raise ValueError("Invalid value for `effective_authentication_type`, length must be less than or equal to `2`")

        self._effective_authentication_type = effective_authentication_type

    @property
    def response_access_token(self):
        """
        Gets the response_access_token of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        A JWT returned by 3DS provider once the authentication is complete, required in cruise hybrid integration method when using CyberSource generated access token. 

        :return: The response_access_token of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._response_access_token

    @response_access_token.setter
    def response_access_token(self, response_access_token):
        """
        Sets the response_access_token of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        A JWT returned by 3DS provider once the authentication is complete, required in cruise hybrid integration method when using CyberSource generated access token. 

        :param response_access_token: The response_access_token of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :type: str
        """
        if response_access_token is not None and len(response_access_token) > 2048:
            raise ValueError("Invalid value for `response_access_token`, length must be less than or equal to `2048`")

        self._response_access_token = response_access_token

    @property
    def signed_pares_status_reason(self):
        """
        Gets the signed_pares_status_reason of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        Provides additional information as to why the PAResStatus has a specific value. 

        :return: The signed_pares_status_reason of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._signed_pares_status_reason

    @signed_pares_status_reason.setter
    def signed_pares_status_reason(self, signed_pares_status_reason):
        """
        Sets the signed_pares_status_reason of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        Provides additional information as to why the PAResStatus has a specific value. 

        :param signed_pares_status_reason: The signed_pares_status_reason of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :type: str
        """
        if signed_pares_status_reason is not None and len(signed_pares_status_reason) > 2:
            raise ValueError("Invalid value for `signed_pares_status_reason`, length must be less than or equal to `2`")

        self._signed_pares_status_reason = signed_pares_status_reason

    @property
    def signed_pares(self):
        """
        Gets the signed_pares of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        Payer authentication result (PARes) message returned by the card-issuing bank. If you need to show proof of enrollment checking, you may need to decrypt and parse the string for the information required by the payment card company. For more information, see \"Storing Payer Authentication Data,\" page 160. Important The value is in base64. You must remove all carriage returns and line feeds before adding the PARes to the request. 

        :return: The signed_pares of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._signed_pares

    @signed_pares.setter
    def signed_pares(self, signed_pares):
        """
        Sets the signed_pares of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        Payer authentication result (PARes) message returned by the card-issuing bank. If you need to show proof of enrollment checking, you may need to decrypt and parse the string for the information required by the payment card company. For more information, see \"Storing Payer Authentication Data,\" page 160. Important The value is in base64. You must remove all carriage returns and line feeds before adding the PARes to the request. 

        :param signed_pares: The signed_pares of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :type: str
        """
        if signed_pares is None:
            raise ValueError("Invalid value for `signed_pares`, must not be `None`")

        self._signed_pares = signed_pares

    @property
    def white_list_status(self):
        """
        Gets the white_list_status of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        Enables the communication of trusted beneficiary/whitelist status between the ACS, the DS and the 3DS Requestor.  Possible Values:  Y - 3DS Requestor is whitelisted by cardholder  N - 3DS Requestor is not whitelisted by cardholder 

        :return: The white_list_status of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :rtype: str
        """
        return self._white_list_status

    @white_list_status.setter
    def white_list_status(self, white_list_status):
        """
        Sets the white_list_status of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        Enables the communication of trusted beneficiary/whitelist status between the ACS, the DS and the 3DS Requestor.  Possible Values:  Y - 3DS Requestor is whitelisted by cardholder  N - 3DS Requestor is not whitelisted by cardholder 

        :param white_list_status: The white_list_status of this Riskv1authenticationresultsConsumerAuthenticationInformation.
        :type: str
        """
        if white_list_status is not None and len(white_list_status) > 1:
            raise ValueError("Invalid value for `white_list_status`, length must be less than or equal to `1`")

        self._white_list_status = white_list_status

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, Riskv1authenticationresultsConsumerAuthenticationInformation):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'first_name': 'str',
        'last_name': 'str',
        'email': 'str',
        'country': 'str',
        'phone_number': 'str'
    }

    attribute_map = {
        'first_name': 'firstName',
        'last_name': 'lastName',
        'email': 'email',
        'country': 'country',
        'phone_number': 'phoneNumber'
    }

    def __init__(self, first_name=None, last_name=None, email=None, country=None, phone_number=None):
        """
        TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo - a model defined in Swagger
        """

        self._first_name = None
        self._last_name = None
        self._email = None
        self._country = None
        self._phone_number = None

        if first_name is not None:
          self.first_name = first_name
        if last_name is not None:
          self.last_name = last_name
        if email is not None:
          self.email = email
        if country is not None:
          self.country = country
        if phone_number is not None:
          self.phone_number = phone_number

    @property
    def first_name(self):
        """
        Gets the first_name of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        Customer’s first name. This name must be the same as the name on the card.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### CyberSource Latin American Processing **Important** For an authorization request, CyberSource Latin American Processing concatenates `orderInformation.billTo.firstName` and `orderInformation.billTo.lastName`. If the concatenated value exceeds 30 characters, CyberSource Latin American Processing declines the authorization request.\\ **Note** CyberSource Latin American Processing is the name of a specific processing connection that CyberSource supports. In the CyberSource API documentation, CyberSource Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called _CyberSource Latin American Processing_. It is not for any other Latin American processors that CyberSource supports.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### For Payouts: This field may be sent only for FDC Compass.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :return: The first_name of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        :rtype: str
        """
        return self._first_name

    @first_name.setter
    def first_name(self, first_name):
        """
        Sets the first_name of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        Customer’s first name. This name must be the same as the name on the card.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### CyberSource Latin American Processing **Important** For an authorization request, CyberSource Latin American Processing concatenates `orderInformation.billTo.firstName` and `orderInformation.billTo.lastName`. If the concatenated value exceeds 30 characters, CyberSource Latin American Processing declines the authorization request.\\ **Note** CyberSource Latin American Processing is the name of a specific processing connection that CyberSource supports. In the CyberSource API documentation, CyberSource Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called _CyberSource Latin American Processing_. It is not for any other Latin American processors that CyberSource supports.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### For Payouts: This field may be sent only for FDC Compass.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :param first_name: The first_name of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        :type: str
        """
        if first_name is not None and len(first_name) > 60:
            raise ValueError("Invalid value for `first_name`, length must be less than or equal to `60`")

        self._first_name = first_name

    @property
    def last_name(self):
        """
        Gets the last_name of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        Customer’s last name. This name must be the same as the name on the card.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### CyberSource Latin American Processing **Important** For an authorization request, CyberSource Latin American Processing concatenates `orderInformation.billTo.firstName` and `orderInformation.billTo.lastName`. If the concatenated value exceeds 30 characters, CyberSource Latin American Processing declines the authorization request.\\ **Note** CyberSource Latin American Processing is the name of a specific processing connection that CyberSource supports. In the CyberSource API documentation, CyberSource Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called CyberSource Latin American Processing. It is not for any other Latin American processors that CyberSource supports.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### For Payouts: This field may be sent only for FDC Compass.  #### OmniPay Direct Optional field.  #### RBS WorldPay Atlanta Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :return: The last_name of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        :rtype: str
        """
        return self._last_name

    @last_name.setter
    def last_name(self, last_name):
        """
        Sets the last_name of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        Customer’s last name. This name must be the same as the name on the card.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### CyberSource Latin American Processing **Important** For an authorization request, CyberSource Latin American Processing concatenates `orderInformation.billTo.firstName` and `orderInformation.billTo.lastName`. If the concatenated value exceeds 30 characters, CyberSource Latin American Processing declines the authorization request.\\ **Note** CyberSource Latin American Processing is the name of a specific processing connection that CyberSource supports. In the CyberSource API documentation, CyberSource Latin American Processing does not refer to the general topic of processing in Latin America. The information in this field description is for the specific processing connection called CyberSource Latin American Processing. It is not for any other Latin American processors that CyberSource supports.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### For Payouts: This field may be sent only for FDC Compass.  #### OmniPay Direct Optional field.  #### RBS WorldPay Atlanta Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :param last_name: The last_name of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        :type: str
        """
        if last_name is not None and len(last_name) > 60:
            raise ValueError("Invalid value for `last_name`, length must be less than or equal to `60`")

        self._last_name = last_name

    @property
    def email(self):
        """
        Gets the email of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        Customer's email address, including the full domain name.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  For processor-specific information, see the `customer_email` request-level field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html)  #### Invoicing Email address for the customer for sending the invoice. If the invoice is in SENT status and email is updated, the old email customer payment link won't work and you must resend the invoice with the new payment link.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :return: The email of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        :rtype: str
        """
        return self._email

    @email.setter
    def email(self, email):
        """
        Sets the email of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        Customer's email address, including the full domain name.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  For processor-specific information, see the `customer_email` request-level field description in [Credit Card Services Using the SCMP API.](http://apps.cybersource.com/library/documentation/dev_guides/CC_Svcs_SCMP_API/html)  #### Invoicing Email address for the customer for sending the invoice. If the invoice is in SENT status and email is updated, the old email customer payment link won't work and you must resend the invoice with the new payment link.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :param email: The email of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        :type: str
        """
        if email is not None and len(email) > 255:
            raise ValueError("Invalid value for `email`, length must be less than or equal to `255`")

        self._email = email

    @property
    def country(self):
        """
        Gets the country of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        Payment card billing country. Use the two-character [ISO Standard Country Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :return: The country of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        :rtype: str
        """
        return self._country

    @country.setter
    def country(self, country):
        """
        Sets the country of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        Payment card billing country. Use the two-character [ISO Standard Country Codes](http://apps.cybersource.com/library/documentation/sbc/quickref/countries_alpha_list.pdf).  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  **Important** It is your responsibility to determine whether a field is required for the transaction you are requesting.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Required when `processingInformation.billPaymentOptions.billPayment=true` and `pointOfSaleInformation.entryMode=keyed`.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :param country: The country of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        :type: str
        """
        if country is not None and len(country) > 2:
            raise ValueError("Invalid value for `country`, length must be less than or equal to `2`")

        self._country = country

    @property
    def phone_number(self):
        """
        Gets the phone_number of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        Customer’s phone number.  It is recommended that you include the country code when the order is from outside the U.S.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### For Payouts: This field may be sent only for FDC Compass.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Optional field.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :return: The phone_number of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        :rtype: str
        """
        return self._phone_number

    @phone_number.setter
    def phone_number(self, phone_number):
        """
        Sets the phone_number of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        Customer’s phone number.  It is recommended that you include the country code when the order is from outside the U.S.  #### Chase Paymentech Solutions Optional field.  ####  Credit Mutuel-CIC Optional field.  #### CyberSource through VisaNet Credit card networks cannot process transactions that contain non-ASCII characters. CyberSource through VisaNet accepts and stores non-ASCII characters correctly and displays them correctly in reports. However, the limitations of the credit card networks prevent CyberSource through VisaNet from transmitting non-ASCII characters to the credit card networks. Therefore, CyberSource through VisaNet replaces non-ASCII characters with meaningless ASCII characters for transmission to the credit card networks.  #### For Payouts: This field may be sent only for FDC Compass.  #### OmniPay Direct Optional field.  #### SIX Optional field.  #### TSYS Acquiring Solutions Optional field.  #### Worldpay VAP Optional field.  #### All other processors Not used. 

        :param phone_number: The phone_number of this TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo.
        :type: str
        """
        if phone_number is not None and len(phone_number) > 15:
            raise ValueError("Invalid value for `phone_number`, length must be less than or equal to `15`")

        self._phone_number = phone_number

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, TssV2TransactionsPost201ResponseEmbeddedOrderInformationBillTo):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other



# coding: utf-8

"""
    CyberSource Merged Spec

    All CyberSource API specs merged together. These are available at https://developer.cybersource.com/api/reference/api-reference.html

    OpenAPI spec version: 0.0.1
    
    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


from pprint import pformat
from six import iteritems
import re


class PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing(object):
    """
    NOTE: This class is auto generated by the swagger code generator program.
    Do not edit the class manually.
    """


    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        'count': 'int',
        'field_name': 'str',
        'information_code': 'str'
    }

    attribute_map = {
        'count': 'count',
        'field_name': 'fieldName',
        'information_code': 'informationCode'
    }

    def __init__(self, count=None, field_name=None, information_code=None):
        """
        PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing - a model defined in Swagger
        """

        self._count = None
        self._field_name = None
        self._information_code = None

        if count is not None:
          self.count = count
        if field_name is not None:
          self.field_name = field_name
        if information_code is not None:
          self.information_code = information_code

    @property
    def count(self):
        """
        Gets the count of this PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing.
        Morphing count specified by the number #.  **Note** The count is not returned for the initial transaction. 

        :return: The count of this PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing.
        :rtype: int
        """
        return self._count

    @count.setter
    def count(self, count):
        """
        Sets the count of this PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing.
        Morphing count specified by the number #.  **Note** The count is not returned for the initial transaction. 

        :param count: The count of this PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing.
        :type: int
        """

        self._count = count

    @property
    def field_name(self):
        """
        Gets the field_name of this PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing.
        Field name of the morphing element. specified by the setting that you chose in the Velocity Editor.  For all possible values, see the `decisionReply_morphingElement_#_fieldName` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :return: The field_name of this PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing.
        :rtype: str
        """
        return self._field_name

    @field_name.setter
    def field_name(self, field_name):
        """
        Sets the field_name of this PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing.
        Field name of the morphing element. specified by the setting that you chose in the Velocity Editor.  For all possible values, see the `decisionReply_morphingElement_#_fieldName` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :param field_name: The field_name of this PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing.
        :type: str
        """
        if field_name is not None and len(field_name) > 255:
            raise ValueError("Invalid value for `field_name`, length must be less than or equal to `255`")

        self._field_name = field_name

    @property
    def information_code(self):
        """
        Gets the information_code of this PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing.
        Identifier that CyberSource assigned to the velocity rule specified by the number #.  For all possible values, see the `decision_velocity_morphing_#_info_code` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :return: The information_code of this PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing.
        :rtype: str
        """
        return self._information_code

    @information_code.setter
    def information_code(self, information_code):
        """
        Sets the information_code of this PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing.
        Identifier that CyberSource assigned to the velocity rule specified by the number #.  For all possible values, see the `decision_velocity_morphing_#_info_code` field description in the _Decision Manager Using the SCMP API Developer Guide_ on the [CyberSource Business Center.](https://ebc2.cybersource.com/ebc2/) Click **Decision Manager** > **Documentation** > **Guides** > _Decision Manager Using the SCMP API Developer Guide_ (PDF link). 

        :param information_code: The information_code of this PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing.
        :type: str
        """
        if information_code is not None and len(information_code) > 255:
            raise ValueError("Invalid value for `information_code`, length must be less than or equal to `255`")

        self._information_code = information_code

    def to_dict(self):
        """
        Returns the model properties as a dict
        """
        result = {}

        for attr, _ in iteritems(self.swagger_types):
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: x.to_dict() if hasattr(x, "to_dict") else x,
                    value
                ))
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], item[1].to_dict())
                    if hasattr(item[1], "to_dict") else item,
                    value.items()
                ))
            else:
                result[attr] = value

        return result

    def to_str(self):
        """
        Returns the string representation of the model
        """
        return pformat(self.to_dict())

    def __repr__(self):
        """
        For `print` and `pprint`
        """
        return self.to_str()

    def __eq__(self, other):
        """
        Returns true if both objects are equal
        """
        if not isinstance(other, PtsV2PaymentsPost201ResponseRiskInformationVelocityMorphing):
            return False

        return self.__dict__ == other.__dict__

    def __ne__(self, other):
        """
        Returns true if both objects are not equal
        """
        return not self == other
